import { IEventParam, Metadata, Singleton, Http } from '@zeedhi/core';
import { Menu, MenuButton } from '@zeedhi/common';
import { LibAuth } from '@zeedhi/tek-lib';
import { DashboardController } from './DashboardController';

@Singleton
export class AppController {
	public microservicePage: boolean = false;

	public toggleMenu({ component }: IEventParam<MenuButton>) {
		const menu = Metadata.getInstance<Menu>(component.menuName);
		menu.toggleMenu();
		if (menu.drawer && !menu.miniState) {
			if (menu.showSearch) {
				setTimeout(() => {
					const searchInput = document.querySelector('.zd-menu-search-input input');
					if (searchInput) (searchInput as HTMLElement).focus();
				}, 100);
			} else {
				const firstMenuItem = document.querySelector('.zd-menu-link, .zd-menu-group > div');
				if (firstMenuItem) (firstMenuItem as HTMLElement).focus();
			}
		}
	}

	get userName() {
		return localStorage.getItem('LOGIN_USER_NAME');
	}

	public showMessageExpiredMenu() {
		LibAuth.getInstance().showMessageExpiredMenu();
	}

	public async updateGraphicForFourMonth({ component }: any) {
		component.loading = true;
		const uri = '/callGraphicForFourMonth';
		const request = await Http.get(uri);
		const values = [request.data.dataset.callGraphicForFourMonth];
		const meses = [];
		const aberto = [];
		const emProcesso = [];
		const aguardando = [];
		const fechado = [];
		if (values.length > 0) {
			for (let i = 0; i < values[0].length; i += 1) {
				meses.push(values[0][i].MES);
				aberto.push(values[0][i].OPENED);
				emProcesso.push(values[0][i].INPROGRESS);
				aguardando.push(values[0][i].WAITING);
				fechado.push(values[0][i].CLOSED);
			}
		}
		const options = {
			series: [
				{
					name: 'Em aberto',
					data: aberto,
				},
				{
					name: 'Fechado',
					data: fechado,
				},
				{
					name: 'Em processo',
					data: emProcesso,
				},
				{
					name: 'Aguardando ação do cliente',
					data: aguardando,
				},
			],
			xaxis: {
				categories: meses,
			},
		};
		component.loading = false;
		component.updateChart(options);
	}

	public async countCallsByTypePieChart({ component }: any) {
		component.loading = true;
		const dashController = new DashboardController();
		const uri = '/countCallsByType';
		const request = await Http.get(uri);
		const values = [request.data.dataset.countCallsByType];
		const tipo = [];
		const quantidade = [];
		if (values.length > 0) {
			for (let i = 0; i < values[0].length; i += 1) {
				tipo.push(values[0][i].TYPE);
				quantidade.push(Number(values[0][i].QUANTITY));
			}
		}
		const newTipo = [];
		if (tipo.length > 0) {
			for (let i = 0; i < tipo.length; i += 1) {
				if (tipo[i] === 'I') {
					newTipo.push('Produto (Zeedhi: App, Browser, Mobile)');
				} else {
					newTipo.push('Produto (Delphi: Windows)');
				}
			}
		}
		const options = {
			labels: newTipo,
			series: quantidade,
			chart: {
				id: 'pie-chart',
				height: '100%',
				toolbar: {
					show: true,
				},
				events: {
					dataPointSelection: dashController.typeChartClick,
				},
			},
		};
		component.loading = false;
		component.updateChart(options);
	}

	public async countCallsByLabelPieChart({ component }: any) {
		component.loading = true;
		const dashController = new DashboardController();
		const uri = '/countCallsByLabel';
		const request = await Http.get(uri);
		const values = [request.data.dataset.countCallsByLabel];
		const chartData = [];
		if (values.length > 0) {
			for (let i = 0; i < values[0].length; i += 1) {
				chartData.push({
					x: values[0][i].LABEL,
					y: Number(values[0][i].QUANTITY),
				});
			}
		}
		const options = {
			series: [
				{
					data: chartData,
				},
			],
			chart: {
				id: 'pie-chart',
				height: 'auto',
				toolbar: {
					show: true,
				},
				events: {
					dataPointSelection: dashController.labelChartClick,
				},
			},
		};
		component.loading = false;
		component.updateChart(options);
	}
}
